==> 0.5.0.tar.gz: lib/widgets/senior_balance.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

enum InfoType { expensive, revennue }

class SeniorBalance extends StatefulWidget {
  final String expenseLabel;
  final String expenseValue;
  final String revenueLabel;
  final String revenueValue;
  final String moneySign;

  const SeniorBalance({
    Key? key,
    required this.expenseLabel,
    required this.expenseValue,
    required this.revenueLabel,
    required this.revenueValue,
    required this.moneySign,
  }) : super(key: key);

  @override
  _SeniorBalanceState createState() => _SeniorBalanceState();
}

class _SeniorBalanceState extends State<SeniorBalance> {
  bool _show = false;
  List<InfoType> items = [InfoType.expensive, InfoType.revennue];
  InfoType _type = InfoType.expensive;

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 64.0,
      width: double.infinity,
      child: Column(
        children: [
          Expanded(
            child: PageView.builder(
              itemCount: 2,
              physics: BouncingScrollPhysics(),
              onPageChanged: (index) {
                setState(() {
                  this._show = false;
                  this._type = items[index];
                });
              },
              itemBuilder: (_, currentIndex) {
                return Container(
                  child: Column(
                    children: [
                      Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          Text(
                            this._type == InfoType.expensive
                                ? widget.expenseLabel
                                : widget.revenueLabel,
                            style: SeniorTypography.small(
                              color: SeniorColors.neutralColor600,
                            ),
                          ),
                          SizedBox(width: 8.0),
                          GestureDetector(
                            onTap: () {
                              setState(() {
                                this._show = !this._show;
                              });
                            },
                            child: Container(
                              padding: EdgeInsets.all(4.0),
                              child: Icon(
                                this._show
                                    ? FontAwesomeIcons.eye
                                    : FontAwesomeIcons.eyeSlash,
                                size: SeniorTypographyIconSize.small,
                                color: SeniorColors.neutralColor600,
                              ),
                            ),
                          )
                        ],
                      ),
                      SizedBox(height: 4.0),
                      Row(
                        crossAxisAlignment: CrossAxisAlignment.end,
                        children: [
                          Text(
                            widget.moneySign,
                            style: SeniorTypography.tiny(
                              color: SeniorColors.neutralColor600,
                            ),
                          ),
                          Visibility(
                            visible: this._show,
                            replacement: Text(
                              '**********',
                              style: SeniorTypography.h3(
                                color: SeniorColors.neutralColor600,
                              ),
                            ),
                            child: Text(
                              this._type == InfoType.expensive ? widget.expenseValue : widget.revenueValue,
                              style: SeniorTypography.h3(
                                color: SeniorColors.neutralColor600,
                              ),
                            ),
                          ),
                        ],
                      ),
                    ],
                  ),
                );
              },
            ),
          ),
          SizedBox(height: 4.0),
          Row(
            children: [
              Container(
                height: 2.0,
                width: 29.0,
                color: this._type == InfoType.expensive
                    ? SeniorColors.neutralColor500
                    : SeniorColors.neutralColor200,
              ),
              SizedBox(width: 2.0),
              Container(
                height: 2.0,
                width: 29.0,
                color: this._type == InfoType.revennue
                    ? SeniorColors.neutralColor500
                    : SeniorColors.neutralColor200,
              ),
            ],
          ),
        ],
      ),
    );
  }
}

==> 0.15.5.tar.gz: lib/widgets/senior_balance.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

enum InfoType { expensive, revennue }

class SeniorBalance extends StatefulWidget {
  final String expenseLabel;
  final String expenseValue;
  final String revenueLabel;
  final String revenueValue;
  final String moneySign;

  const SeniorBalance({
    Key? key,
    required this.expenseLabel,
    required this.expenseValue,
    required this.revenueLabel,
    required this.revenueValue,
    required this.moneySign,
  }) : super(key: key);

  @override
  _SeniorBalanceState createState() => _SeniorBalanceState();
}

class _SeniorBalanceState extends State<SeniorBalance> {
  bool _show = false;
  List<InfoType> items = [InfoType.expensive, InfoType.revennue];
  InfoType _type = InfoType.expensive;

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 64.0,
      width: double.infinity,
      child: Column(
        children: [
          Expanded(
            child: PageView.builder(
              itemCount: 2,
              physics: BouncingScrollPhysics(),
              onPageChanged: (index) {
                setState(() {
                  _show = false;
                  _type = items[index];
                });
              },
              itemBuilder: (_, currentIndex) {
                return Container(
                  child: Column(
                    children: [
                      Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          Text(
                            _type == InfoType.expensive
                                ? widget.expenseLabel
                                : widget.revenueLabel,
                            style: SeniorTypography.small(
                              color: SeniorColors.neutralColor600,
                            ),
                          ),
                          SizedBox(width: 8.0),
                          GestureDetector(
                            onTap: () {
                              setState(() {
                                _show = !_show;
                              });
                            },
                            child: Container(
                              padding: EdgeInsets.all(4.0),
                              child: Icon(
                                _show
                                    ? FontAwesomeIcons.eye
                                    : FontAwesomeIcons.eyeSlash,
                                size: SeniorTypographyIconSize.small,
                                color: SeniorColors.neutralColor600,
                              ),
                            ),
                          )
                        ],
                      ),
                      SizedBox(height: 4.0),
                      Row(
                        crossAxisAlignment: CrossAxisAlignment.end,
                        children: [
                          Text(
                            widget.moneySign,
                            style: SeniorTypography.tiny(
                              color: SeniorColors.neutralColor600,
                            ),
                          ),
                          Visibility(
                            visible: _show,
                            replacement: Text(
                              '**********',
                              style: SeniorTypography.h3(
                                color: SeniorColors.neutralColor600,
                              ),
                            ),
                            child: Text(
                              _type == InfoType.expensive ? widget.expenseValue : widget.revenueValue,
                              style: SeniorTypography.h3(
                                color: SeniorColors.neutralColor600,
                              ),
                            ),
                          ),
                        ],
                      ),
                    ],
                  ),
                );
              },
            ),
          ),
          SizedBox(height: 4.0),
          Row(
            children: [
              Container(
                height: 2.0,
                width: 29.0,
                color: _type == InfoType.expensive
                    ? SeniorColors.neutralColor500
                    : SeniorColors.neutralColor200,
              ),
              SizedBox(width: 2.0),
              Container(
                height: 2.0,
                width: 29.0,
                color: _type == InfoType.revennue
                    ? SeniorColors.neutralColor500
                    : SeniorColors.neutralColor200,
              ),
            ],
          ),
        ],
      ),
    );
  }
}
